@@ -19,7 +19,6 @@ from itertools import chain
 
 from django.template.loader import get_template
 from django.template import Context
-from django.utils import html
 from django.utils.translation import ugettext as _  # noqa
 
 from horizon import exceptions
@@ -48,6 +47,21 @@ class ExpressionWidget(forms.Widget):
         return t.render(context)
 
 
+class MatchByWidget(forms.Widget):
+    def __init__(self, initial, attrs=None):
+        super(MatchByWidget, self).__init__(attrs)
+        self.initial = initial
+
+    def render(self, name, value, attrs):
+        final_attrs = self.build_attrs(attrs, name=name)
+        t = get_template(constants.TEMPLATE_PREFIX + 'match_by_field.html')
+
+        local_attrs = {'service': ''}
+        local_attrs.update(final_attrs)
+        context = Context(local_attrs)
+        return t.render(context)
+
+
 class NotificationField(forms.MultiValueField):
     def __init__(self, *args, **kwargs):
         super(NotificationField, self).__init__(*args, **kwargs)
@@ -78,10 +92,19 @@ class NotificationCreateWidget(forms.Select):
         final_attrs = self.build_attrs(attrs, name=name)
         tpl = get_template(constants.TEMPLATE_PREFIX + 'notification_field.html')
 
-        selected = [item['id'] for item in value] if value else []
+        selected = {}
+        for item in value if value else []:
+            selected[item['id']] = {'alarm': item['alarm'],
+                                    'ok': item['ok'],
+                                    'undetermined': item['undetermined']}
         data = []
         for id, label, type, address in chain(self.choices, choices):
-            data.append((id, label, type, address, id in selected))
+            if id in selected:
+                actions = selected[id]
+                data.append((id, label, type, address, actions['alarm'],
+                             actions['ok'], actions['undetermined'], True))
+            else:
+                data.append((id, label, type, address, True, True, True, False))
 
         local_attrs = {'data': json.dumps(data)}
         local_attrs.update(final_attrs)
@@ -102,12 +125,12 @@ class BaseAlarmForm(forms.SelfHandlingForm):
         choiceWidget = forms.Select
         if create:
             expressionWidget = ExpressionWidget(initial)
+            matchByWidget = MatchByWidget(initial)
             notificationWidget = NotificationCreateWidget()
-            matchByAttr = None
         else:
             expressionWidget = textWidget
+            matchByWidget = forms.TextInput(attrs={'readonly': 'readonly'})
             notificationWidget = NotificationCreateWidget()
-            matchByAttr = {'readonly': 'readonly'}
 
         self.fields['name'] = forms.CharField(label=_("Name"),
                                               required=required,
@@ -120,8 +143,7 @@ class BaseAlarmForm(forms.SelfHandlingForm):
                                                     help_text=_("An alarm expression."))
         self.fields['match_by'] = forms.CharField(label=_("Match by"),
                                                   required=False,
-                                                  initial="url,hostname,component,service",
-                                                  widget=forms.TextInput(attrs=matchByAttr),
+                                                  widget=matchByWidget,
                                                   help_text=_("The metric dimensions used "
                                                               "to create unique alarms."))
         self.fields['description'] = forms.CharField(label=_("Description"),
@@ -151,6 +173,15 @@ class BaseAlarmForm(forms.SelfHandlingForm):
             widget=notificationWidget,
             help_text=_("Notification methods. "
                         "Notifications can be sent when an alarm state transition occurs."))
+        self.fields['alarm_actions'] = NotificationField(
+            label=_("Alarm Actions"),
+            widget=forms.MultipleHiddenInput())
+        self.fields['ok_actions'] = NotificationField(
+            label=_("OK Actions"),
+            widget=forms.MultipleHiddenInput())
+        self.fields['undetermined_actions'] = NotificationField(
+            label=_("Undetermined Actions"),
+            widget=forms.MultipleHiddenInput())
 
     def set_notification_choices(self, request):
         try:
@@ -189,18 +220,16 @@ class CreateAlarmForm(BaseAlarmForm):
 
     def handle(self, request, data):
         try:
-            alarm_actions = [notification.get('id')
-                             for notification in data['notifications']]
             api.monitor.alarmdef_create(
                 request,
                 name=data['name'],
                 expression=data['expression'],
                 description=data['description'],
                 severity=data['severity'],
-                match_by=data['match_by'].split(',') if data['match_by'] else None,
-                alarm_actions=alarm_actions,
-                ok_actions=alarm_actions,
-                undetermined_actions=alarm_actions,
+                match_by=data['match_by'].split(',') if data['match_by'] else [],
+                alarm_actions=data['alarm_actions'],
+                ok_actions=data['ok_actions'],
+                undetermined_actions=data['undetermined_actions'],
             )
             messages.success(request,
                              _('Alarm Definition has been created successfully.'))
@@ -218,11 +247,7 @@ class EditAlarmForm(BaseAlarmForm):
 
     def handle(self, request, data):
         try:
-            alarm_actions = []
             alarm_def = api.monitor.alarmdef_get(request, self.initial['id'])
-            if data['notifications']:
-                alarm_actions = [notification.get('id')
-                                 for notification in data['notifications']]
             api.monitor.alarmdef_update(
                 request,
                 alarm_id=self.initial['id'],
@@ -230,11 +255,11 @@ class EditAlarmForm(BaseAlarmForm):
                 name=data['name'],
                 expression=data['expression'],
                 description=data['description'],
-                match_by = alarm_def['match_by'],
+                match_by=alarm_def['match_by'],
                 actions_enabled=data['actions_enabled'],
-                alarm_actions=alarm_actions,
-                ok_actions=alarm_actions,
-                undetermined_actions=alarm_actions,
+                alarm_actions=data['alarm_actions'],
+                ok_actions=data['ok_actions'],
+                undetermined_actions=data['undetermined_actions'],
             )
             messages.success(request,
                              _('Alarm definition has been updated.'))
