@@ -27,6 +27,7 @@ from django.utils.translation import ugettext_lazy as _  # noqa
 from horizon import tables
 
 from monitoring.alarms import constants
+from monitoring.config import local_settings
 from monitoring.overview import constants as ov_constants
 from monitoring import api
 
@@ -158,14 +159,27 @@ class GraphMetric(tables.LinkAction):
         return super(self, GraphMetric).render()
 
     def get_link_url(self, datum):
-        name = datum['metrics'][0]['name']
-        threshold = json.dumps(datum['metrics'])
-        endpoint = str(reverse_lazy(ov_constants.URL_PREFIX + 'proxy'))
-        endpoint = self.table.request.build_absolute_uri(endpoint)
+        url = ''
+        query = ''
         self.attrs['target'] = '_blank'
-        url = (settings.STATIC_URL or '') + \
-            'grafana/index.html#/dashboard/script/detail.js'
-        query = "?name=%s&threshold=%s&api=%s" % \
+        try:
+            region = self.table.request.user.services_region
+            grafana_url = getattr(local_settings, 'GRAFANA_URL').get(region, '')
+            url = grafana_url + \
+                '/dashboard/script/drilldown.js'
+            metric = datum['metrics'][0]['name']
+            dimensions = datum['metrics'][0].get('dimensions', {})
+            query = "?metric=%s" % metric
+            for key, value in dimensions.iteritems():
+                query += "&%s=%s" % (key, value)
+        except AttributeError:
+            # Catches case where Grafana 2 is not enabled.
+            name = datum['metrics'][0]['name']
+            threshold = json.dumps(datum['metrics'])
+            endpoint = str(reverse_lazy(ov_constants.URL_PREFIX + 'proxy'))
+            endpoint = self.table.request.build_absolute_uri(endpoint)
+            url = '/grafana/index.html#/dashboard/script/detail.js'
+            query = "?name=%s&threshold=%s&api=%s" % \
                 (name, threshold, endpoint)
         return url + query
 
