@@ -14,19 +14,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import json
 import logging
 import urllib
 import urllib2
 
+from django import http
 from django.contrib import messages
 from django.core.urlresolvers import reverse_lazy
 from django.http import HttpResponse  # noqa
-from django.views.generic import TemplateView  # noqa
 from django.utils.translation import ugettext_lazy as _  # noqa
-from django import http
-from django.views.decorators.csrf import csrf_exempt
 from django.views import generic
+from django.views.decorators.csrf import csrf_exempt
+from django.views.generic import TemplateView  # noqa
+from openstack_auth import utils as auth_utils
 from openstack_dashboard import policy
 
 from monitoring import api
@@ -34,7 +36,6 @@ from monitoring.alarms import tables as alarm_tables
 from monitoring.config import local_settings as settings
 from monitoring.overview import constants
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -190,7 +191,8 @@ def generate_status(request):
         service = alarm_tables.get_service(a)
         service_alarms = alarms_by_service.setdefault(service, [])
         service_alarms.append(a)
-    for row in get_monitoring_services(request):
+    monitoring_services = copy.deepcopy(get_monitoring_services(request))
+    for row in monitoring_services:
         row['name'] = unicode(row['name'])
         if 'groupBy' in row:
             alarms_by_group = {}
@@ -215,7 +217,7 @@ def generate_status(request):
                 service['class'] = get_status(service_alarms)
                 service['icon'] = get_icon(service['class'])
                 service['display'] = unicode(service['display'])
-    return get_monitoring_services(request)
+    return monitoring_services
 
 
 class IndexView(TemplateView):
@@ -223,9 +225,14 @@ class IndexView(TemplateView):
 
     def get_context_data(self, **kwargs):
         context = super(IndexView, self).get_context_data(**kwargs)
-        proxy_url_path = str(reverse_lazy(constants.URL_PREFIX + 'proxy'))
-        api_root = self.request.build_absolute_uri(proxy_url_path)
-        context["api"] = api_root
+        try:
+            region = self.request.user.services_region
+            context["grafana_url"] = getattr(settings, 'GRAFANA_URL').get(region, '')
+        except AttributeError:
+            # Catches case where Grafana 2 is not enabled.
+            proxy_url_path = str(reverse_lazy(constants.URL_PREFIX + 'proxy'))
+            api_root = self.request.build_absolute_uri(proxy_url_path)
+            context["api"] = api_root
         context["dashboards"] = get_dashboard_links(self.request)
         context['can_access_logs'] = policy.check(
             (('identity', 'admin_required'), ), self.request
@@ -344,7 +351,9 @@ class KibanaProxyView(generic.View):
 
         except urllib2.HTTPError as e:
             return http.HttpResponse(
-                e.read(), status=e.code
+                e.read(),
+                status=e.code,
+                content_type=e.hdrs['content-type']
             )
         except urllib2.URLError as e:
             return http.HttpResponse(e.reason, 404)
@@ -365,6 +374,13 @@ class KibanaProxyView(generic.View):
         if request.method not in self.http_method_names:
             return http.HttpResponseNotAllowed(request.method)
 
+        if not self._can_access_kibana():
+            error_msg = (_('User %s does not have sufficient '
+                           'privileges to access Kibana')
+                         % auth_utils.get_user(request))
+            LOG.error(error_msg)
+            return http.HttpResponseForbidden(content=error_msg)
+
         # passing kbn version explicitly for kibana >= 4.3.x
         headers = {
             'X-Auth-Token': request.user.token.id,
@@ -383,3 +399,8 @@ class KibanaProxyView(generic.View):
 
     def get_absolute_url(self, url):
         return self.base_url + self.get_relative_url(url).lstrip('/')
+
+    def _can_access_kibana(self):
+        return policy.check(
+            (('identity', 'admin_required'),), self.request
+        )
