@@ -37,7 +37,7 @@ angular.module('monitoring.controllers', [])
              // overwrite to new values
              queryParams['ts_mode'] = nval;
              if(nval === 'utc'){
-               queryParams['ts_offset'] = 0
+               queryParams['ts_offset'] = 0;
              } else {
                queryParams['ts_offset'] = offset;
              }
@@ -152,28 +152,45 @@ angular.module('monitoring.controllers', [])
         $scope.currentFunction = "max";
         $scope.currentComparator = ">";
         $scope.currentThreshold = 0;
+        $scope.currentIsDeterministic = false;
         $scope.matchingMetrics= [];
         $scope.tags = [];
+        $scope.matchByTags = [];
         $scope.possibleDimensions = function(query) {
-            var deferred = $q.defer();
-            var dim = {}
-            var dimList = []
-            angular.forEach($scope.matchingMetrics, function(value, name) {
-                for (var key in value.dimensions) {
-                    if (value.dimensions.hasOwnProperty(key)) {
-                        var dimStr = key + "=" + value.dimensions[key]
-                        if (dimStr.indexOf(query) === 0) {
-                            dim[dimStr] = dimStr;
+            return $q(function(resolve, reject) {
+                var dim = {}
+                var dimList = []
+                angular.forEach($scope.matchingMetrics, function(value, name) {
+                    for (var key in value.dimensions) {
+                        if (value.dimensions.hasOwnProperty(key)) {
+                            var dimStr = key + "=" + value.dimensions[key]
+                            if (dimStr.indexOf(query) === 0) {
+                                dim[dimStr] = dimStr;
+                            }
                         }
                     }
-                }
+                });
+                angular.forEach(dim, function(value, name) {
+                    dimList.push(value);
+                });
+                resolve(dimList);
             });
-            angular.forEach(dim, function(value, name) {
-                dimList.push(value)
-            });
-            deferred.resolve(dimList);
-            return deferred.promise;
         };
+        $scope.possibleDimKeys = function(query) {
+            return $q(function(resolve, reject) {
+                var dimList = []
+                angular.forEach($scope.matchingMetrics, function(value, name) {
+                    for (var key in value.dimensions) {
+                        if (key.indexOf(query) === 0) {
+                            if (dimList.indexOf(key) < 0) {
+                                dimList.push(key);
+                            }
+                        }
+                    }
+                });
+                resolve(dimList);
+            });
+        }
         $scope.metricChanged = function() {
             if ($scope.defaultTag.length > 0) {
                 $scope.tags = [{text: $scope.defaultTag}];
@@ -181,7 +198,7 @@ angular.module('monitoring.controllers', [])
             $scope.saveDimension();
         }
         $scope.saveExpression = function() {
-            $('#dimension').val($scope.formatDimension());
+            $('#expression').val($scope.formatDimension());
         }
         $scope.saveDimension = function() {
             $scope.saveExpression();
@@ -206,15 +223,30 @@ angular.module('monitoring.controllers', [])
             $scope.dimnames = ['name', 'dimensions'];
             $('#match').val($scope.formatMatchBy());
         }
+        $scope.saveDimKey = function() {
+            var matchByTags = []
+            for (var i = 0; i < $scope.matchByTags.length; i++) {
+                matchByTags.push($scope.matchByTags[i]['text'])
+            }
+            $('#id_match_by').val(matchByTags.join(','));
+        }
         $scope.formatDimension = function() {
-            var dim = ''
+            var dim = '';
             angular.forEach($scope.tags, function(value, key) {
                 if (dim.length) {
-                    dim += ','
+                    dim += ',';
                 }
-                dim += value['text']
+                dim += value['text'];
             })
-            return $scope.currentFunction + '(' + $scope.currentMetric + '{' + dim + '}) ' + $scope.currentComparator + ' ' + $scope.currentThreshold;
+            return $scope.currentFunction
+                    + '('
+                    + $scope.currentMetric
+                    + '{' + dim + '}'
+                    + ($scope.currentIsDeterministic ? ',deterministic' : '')
+                    + ') '
+                    + $scope.currentComparator
+                    + ' '
+                    + $scope.currentThreshold;
         }
         $scope.formatMatchBy = function() {
             var dimNames = {}
@@ -233,6 +265,18 @@ angular.module('monitoring.controllers', [])
             $scope.saveDimension();
         }
 
+        $scope.$on('$destroy', (function() {
+            var detWatcher = $scope.$watch('currentIsDeterministic', function detWatcher(newValue, oldValue) {
+                if(newValue != oldValue){
+                    $scope.$emit('mon_deterministic_changed', newValue);
+                }
+            });
+            return function() {
+                // destroy watchers
+                detWatcher();
+            }
+        }()));
+
         function uniqueNames(input, key) {
             var unique = {};
             var uniqueList = [];
@@ -247,10 +291,11 @@ angular.module('monitoring.controllers', [])
     }])
     .controller('alarmNotificationFieldController', NotificationField);
 
-function NotificationField(){
+function NotificationField($rootScope) {
 
     var vm = this;
     var allOptions = {};
+    var oldUndetermined = {};
 
     vm.empty = true;
     vm.list = [];
@@ -258,6 +303,7 @@ function NotificationField(){
         model:null,
         options:[]
     };
+    vm.isDeterministic = false;
 
 
     vm.init = function(data){
@@ -282,16 +328,24 @@ function NotificationField(){
             }
         }
         vm.select.model = null;
+        if (id in oldUndetermined) {
+            delete oldUndetermined[id];
+        }
     };
 
+    $rootScope.$on('mon_deterministic_changed', onDeterministicChange)
+
     function prepareNotify(item){
-        var selected = item[4]
+        var selected = item[7]
         var notify = {
             id: item[0],
             label: item[1] +' ('+ item[2] +')',
             name: item[1],
             type: item[2],
-            address: item[3]
+            address: item[3],
+            alarm: item[4],
+            ok: item[5],
+            undetermined: item[6]
         };
         allOptions[notify.id] = notify;
         if(selected){
@@ -310,9 +364,33 @@ function NotificationField(){
             }
          }
     }
+
+    function onDeterministicChange(event, isDeterministic) {
+
+        if (!(vm.list && vm.list.length)) {
+            return;
+        } else if (isDeterministic === vm.isDeterministic) {
+            return;
+        }
+
+        vm.isDeterministic = isDeterministic;
+
+        angular.forEach(vm.list, function(item) {
+            if(!(item.id in oldUndetermined)){
+                oldUndetermined[item.id] = [];
+            }
+            if (isDeterministic) {
+                oldUndetermined[item.id] = item.undetermined;
+                item.undetermined = !isDeterministic;
+            } else {
+                item.undetermined = oldUndetermined[item.id];
+                delete oldUndetermined[item.id];
+            }
+        });
+    }
 }
 
-NotificationField.$inject = [];
+NotificationField.$inject = ['$rootScope'];
 
 angular.module('monitoring.filters', [])
     .filter('spacedim', function () {
@@ -321,4 +399,4 @@ angular.module('monitoring.filters', [])
                 return text;
             return JSON.stringify(text).split(',').join(', ');
         }
-    })
+    });
